Documentation
¶
Overview ¶
@Title @Description @Author Wangwengang 2023/12/12 14:17 @Update Wangwengang 2023/12/12 14:17
@Title @Description @Author Wangwengang 2023/12/12 09:15 @Update Wangwengang 2023/12/12 09:15
@Title @Description @Author Wangwengang 2023/12/10 12:44 @Update Wangwengang 2023/12/10 12:44
Index ¶
- Constants
- Variables
- func ByteArrayToString(buf [][][]byte) string
- func CreateDir(dirs ...string) (err error)
- func DeLFile(filePath string) error
- func FileExist(path string) bool
- func FileMove(src string, dst string) (err error)
- func GenerateAESKey(keySize int) (string, error)
- func GenerateRandomString(length int) (string, error)
- func GenerateTLSConfig() (*tls.Config, error)
- func HmacSha1(key, data []byte) []byte
- func MD5V(str []byte, b ...byte) string
- func PathExists(path string) (bool, error)
- func ReverseByteArray(s [][][]byte) [][][]byte
- func StrToInt64(str string) int64
- func Tail(path string, num int) string
- func TrimSpace(target interface{})
- type BrotliCompressor
- type Fnv32Hash
- type IDWorker
- type IHash
- type IterCb
- type RemoveCb
- type ShardLockMaps
- func (slm ShardLockMaps) Clear()
- func (slm ShardLockMaps) Count() int
- func (slm ShardLockMaps) Get(key string) (interface{}, bool)
- func (slm ShardLockMaps) GetShard(key string) *SingleShardMap
- func (slm ShardLockMaps) Has(key string) bool
- func (slm ShardLockMaps) IsEmpty() bool
- func (slm ShardLockMaps) Items() map[string]interface{}
- func (slm ShardLockMaps) IterBuffered() <-chan Tuple
- func (slm ShardLockMaps) IterCb(fn IterCb)
- func (slm ShardLockMaps) Keys() []string
- func (slm ShardLockMaps) MSet(data map[string]interface{})
- func (slm ShardLockMaps) MarshalJSON() ([]byte, error)
- func (slm ShardLockMaps) Pop(key string) (v interface{}, exists bool)
- func (slm ShardLockMaps) Remove(key string)
- func (slm ShardLockMaps) RemoveCb(key string, cb RemoveCb) bool
- func (slm ShardLockMaps) Set(key string, value interface{})
- func (slm ShardLockMaps) SetNX(key string, value interface{}) bool
- func (slm ShardLockMaps) UnmarshalJSON(b []byte) (err error)
- type SingleShardMap
- type Tuple
Constants ¶
const ( Prime = 16777619 HashVal = 2166136261 )
Variables ¶
var AcceptDelay *acceptDelay
var ShardCount = 32
Functions ¶
func ByteArrayToString ¶
func GenerateAESKey ¶
GenerateAESKey 生成指定字节长度的随机密钥 选择密钥长度:16 (128-bit), 24 (192-bit), 32 (256-bit)
func GenerateRandomString ¶
GenerateRandomString 生成随机字符串 length为字节长度,编码后长度会不同
func GenerateTLSConfig ¶
func PathExists ¶
func ReverseByteArray ¶
Types ¶
type BrotliCompressor ¶
type BrotliCompressor struct{}
type IDWorker ¶
type IDWorker struct {
// contains filtered or unexported fields
}
func NewIDWorker ¶
type IHash ¶
func DefaultHash ¶
func DefaultHash() IHash
type IterCb ¶
type IterCb func(key string, v interface{})
IterCb Iterator callback,called for every key,value found in maps. RLock is held for all calls for a given shard therefore callback sess consistent view of a shard, but not across the shards
type RemoveCb ¶
RemoveCb is a callback executed in a map.RemoveCb() call, while Lock is held If returns true, the element will be removed from the map
type ShardLockMaps ¶
type ShardLockMaps struct {
// contains filtered or unexported fields
}
ShardLockMaps A "thread" safe map of type string:Anything. To avoid lock bottlenecks this map is dived to several (ShardCount) map shards.
func NewShardLockMaps ¶
func NewShardLockMaps() ShardLockMaps
NewShardLockMaps Creates a new ShardLockMaps.
func NewWithCustomHash ¶
func NewWithCustomHash(hash IHash) ShardLockMaps
func (ShardLockMaps) Count ¶
func (slm ShardLockMaps) Count() int
Count returns the number of elements within the map.
func (ShardLockMaps) Get ¶
func (slm ShardLockMaps) Get(key string) (interface{}, bool)
Get retrieves an element from map under given key.
func (ShardLockMaps) GetShard ¶
func (slm ShardLockMaps) GetShard(key string) *SingleShardMap
GetShard returns shard under given key
func (ShardLockMaps) Has ¶
func (slm ShardLockMaps) Has(key string) bool
Has Looks up an item under specified key
func (ShardLockMaps) IsEmpty ¶
func (slm ShardLockMaps) IsEmpty() bool
IsEmpty checks if map is empty.
func (ShardLockMaps) Items ¶
func (slm ShardLockMaps) Items() map[string]interface{}
Items returns all items as map[string]interface{}
func (ShardLockMaps) IterBuffered ¶
func (slm ShardLockMaps) IterBuffered() <-chan Tuple
IterBuffered returns a buffered iterator which could be used in a for range loop.
func (ShardLockMaps) IterCb ¶
func (slm ShardLockMaps) IterCb(fn IterCb)
IterCb Callback based iterator, cheapest way to read all elements in a map.
func (ShardLockMaps) Keys ¶
func (slm ShardLockMaps) Keys() []string
Keys returns all keys as []string
func (ShardLockMaps) MSet ¶
func (slm ShardLockMaps) MSet(data map[string]interface{})
MSet Sets the given value under the specified key.
func (ShardLockMaps) MarshalJSON ¶
func (slm ShardLockMaps) MarshalJSON() ([]byte, error)
MarshalJSON Reviles ConcurrentMap "private" variables to json marshal.
func (ShardLockMaps) Pop ¶
func (slm ShardLockMaps) Pop(key string) (v interface{}, exists bool)
Pop removes an element from the map and returns it
func (ShardLockMaps) Remove ¶
func (slm ShardLockMaps) Remove(key string)
Remove removes an element from the map.
func (ShardLockMaps) RemoveCb ¶
func (slm ShardLockMaps) RemoveCb(key string, cb RemoveCb) bool
RemoveCb locks the shard containing the key, retrieves its current value and calls the callback with those params If callback returns true and element exists, it will remove it from the map Returns the value returned by the callback (even if element was not present in the map)
func (ShardLockMaps) Set ¶
func (slm ShardLockMaps) Set(key string, value interface{})
Set Sets the given value under the specified key.
func (ShardLockMaps) SetNX ¶
func (slm ShardLockMaps) SetNX(key string, value interface{}) bool
SetNX Sets the given value under the specified key if no value was associated with it.
func (ShardLockMaps) UnmarshalJSON ¶
func (slm ShardLockMaps) UnmarshalJSON(b []byte) (err error)
UnmarshalJSON Reverse process of Marshal.
type SingleShardMap ¶
SingleShardMap A "thread" safe string to anything map.